# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/fastpolvo',
                'doc_host': 'https://lgvaz.github.io',
                'git_url': 'https://github.com/lgvaz/fastpolvo',
                'lib_path': 'fastpolvo'},
  'syms': { 'fastpolvo.classification.baseline.baseline': { 'fastpolvo.classification.baseline.baseline.FastaiMetricWrapper': ( 'classification.baseline.baseline.html#fastaimetricwrapper',
                                                                                                                                'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.FastaiMetricWrapper.__init__': ( 'classification.baseline.baseline.html#fastaimetricwrapper.__init__',
                                                                                                                                         'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.FastaiMetricWrapper.accumulate': ( 'classification.baseline.baseline.html#fastaimetricwrapper.accumulate',
                                                                                                                                           'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.calculate_metrics': ( 'classification.baseline.baseline.html#calculate_metrics',
                                                                                                                              'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.fixed_probs': ( 'classification.baseline.baseline.html#fixed_probs',
                                                                                                                        'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.random_probs': ( 'classification.baseline.baseline.html#random_probs',
                                                                                                                         'fastpolvo/classification/baseline/baseline.py')},
            'fastpolvo.classification.explorer': { 'fastpolvo.classification.explorer.DataExplorer': ( 'classification.explorer.html#dataexplorer',
                                                                                                       'fastpolvo/classification/explorer.py'),
                                                   'fastpolvo.classification.explorer.DataExplorer.__init__': ( 'classification.explorer.html#dataexplorer.__init__',
                                                                                                                'fastpolvo/classification/explorer.py'),
                                                   'fastpolvo.classification.explorer.DataExplorer.from_datasets': ( 'classification.explorer.html#dataexplorer.from_datasets',
                                                                                                                     'fastpolvo/classification/explorer.py')},
            'fastpolvo.core': { 'fastpolvo.core.one_batch_with_idxs': ('core.html#one_batch_with_idxs', 'fastpolvo/core.py'),
                                'fastpolvo.core.show_tfms': ('core.html#show_tfms', 'fastpolvo/core.py')},
            'fastpolvo.data.transforms': { 'fastpolvo.data.transforms.AlignOrientation': ( 'data.transforms.html#alignorientation',
                                                                                           'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.AlignOrientation.__init__': ( 'data.transforms.html#alignorientation.__init__',
                                                                                                    'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.AlignOrientation.encodes': ( 'data.transforms.html#alignorientation.encodes',
                                                                                                   'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.FlipVert': ( 'data.transforms.html#flipvert',
                                                                                   'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.FlipVert.__init__': ( 'data.transforms.html#flipvert.__init__',
                                                                                            'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.FlipVert.encodes': ( 'data.transforms.html#flipvert.encodes',
                                                                                           'fastpolvo/data/transforms.py')},
            'fastpolvo.segmentation.core': { 'fastpolvo.segmentation.core.SegmentationExplorer': ( 'segmentation.core.html#segmentationexplorer',
                                                                                                   'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer.__init__': ( 'segmentation.core.html#segmentationexplorer.__init__',
                                                                                                            'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer._group_y': ( 'segmentation.core.html#segmentationexplorer._group_y',
                                                                                                            'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer.from_datasets': ( 'segmentation.core.html#segmentationexplorer.from_datasets',
                                                                                                                 'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer.most_common_appearances': ( 'segmentation.core.html#segmentationexplorer.most_common_appearances',
                                                                                                                           'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer.most_common_pixels': ( 'segmentation.core.html#segmentationexplorer.most_common_pixels',
                                                                                                                      'fastpolvo/segmentation/core.py')}}}
